@@ -1,5 +1,6 @@
 use std::fs;
 use std::marker::PhantomData;
+use std::panic::panic_any;
 use std::path::{Path, PathBuf};
 use std::sync::Mutex;
 
@@ -239,7 +240,8 @@ impl<'a, Tree: 'static + MerkleTreeTrait, G: 'static + Hasher> StackedDrg<'a, Tr
                                 let labeled_node = rcp.c_x.get_node_at_layer(layer)?;
                                 assert!(
                                     proof.verify(&pub_inputs.replica_id, &labeled_node),
-                                    format!("Invalid encoding proof generated at layer {}", layer)
+                                    "Invalid encoding proof generated at layer {}",
+                                    layer,
                                 );
                                 trace!("Valid encoding proof generated at layer {}", layer);
                             }
@@ -311,16 +313,31 @@ impl<'a, Tree: 'static + MerkleTreeTrait, G: 'static + Hasher> StackedDrg<'a, Tr
     ) -> Result<(Labels<Tree>, Vec<LayerState>)> {
         let mut parent_cache = graph.parent_cache()?;
 
-        if SETTINGS.use_multicore_sdr {
-            info!("multi core replication");
-            create_label::multi::create_labels_for_encoding(
-                graph,
-                &parent_cache,
-                layer_challenges.layers(),
-                replica_id,
-                config,
-            )
-        } else {
+        #[cfg(feature = "multicore-sdr")]
+        {
+            if SETTINGS.use_multicore_sdr {
+                info!("multi core replication");
+                create_label::multi::create_labels_for_encoding(
+                    graph,
+                    &parent_cache,
+                    layer_challenges.layers(),
+                    replica_id,
+                    config,
+                )
+            } else {
+                info!("single core replication");
+                create_label::single::create_labels_for_encoding(
+                    graph,
+                    &mut parent_cache,
+                    layer_challenges.layers(),
+                    replica_id,
+                    config,
+                )
+            }
+        }
+
+        #[cfg(not(feature = "multicore-sdr"))]
+        {
             info!("single core replication");
             create_label::single::create_labels_for_encoding(
                 graph,
@@ -341,16 +358,31 @@ impl<'a, Tree: 'static + MerkleTreeTrait, G: 'static + Hasher> StackedDrg<'a, Tr
     ) -> Result<LabelsCache<Tree>> {
         let mut parent_cache = graph.parent_cache()?;
 
-        if SETTINGS.use_multicore_sdr {
-            info!("multi core replication");
-            create_label::multi::create_labels_for_decoding(
-                graph,
-                &parent_cache,
-                layer_challenges.layers(),
-                replica_id,
-                config,
-            )
-        } else {
+        #[cfg(feature = "multicore-sdr")]
+        {
+            if SETTINGS.use_multicore_sdr {
+                info!("multi core replication");
+                create_label::multi::create_labels_for_decoding(
+                    graph,
+                    &parent_cache,
+                    layer_challenges.layers(),
+                    replica_id,
+                    config,
+                )
+            } else {
+                info!("single core replication");
+                create_label::single::create_labels_for_decoding(
+                    graph,
+                    &mut parent_cache,
+                    layer_challenges.layers(),
+                    replica_id,
+                    config,
+                )
+            }
+        }
+
+        #[cfg(not(feature = "multicore-sdr"))]
+        {
             info!("single core replication");
             create_label::single::create_labels_for_decoding(
                 graph,
@@ -1238,7 +1270,7 @@ impl<'a, Tree: 'static + MerkleTreeTrait, G: 'static + Hasher> StackedDrg<'a, Tr
                 )?;
                 tree_c.root()
             }
-            _ => panic!("Unsupported column arity"),
+            _ => panic_any("Unsupported column arity"),
         };
         info!("tree_c done");
 
